@@ -27,16 +27,24 @@
 #include "accountbalanceparser.h"
 #include "activity.h"
 #include "activityparser.h"
+#include "privatedata.h"
+#include "privatedataparser.h"
 #include "category.h"
 #include "categoryparser.h"
+#include "comment.h"
+#include "commentparser.h"
 #include "content.h"
 #include "contentparser.h"
+#include "distribution.h"
+#include "distributionparser.h"
 #include "downloaditem.h"
 #include "downloaditemparser.h"
 #include "event.h"
 #include "eventparser.h"
 #include "folder.h"
 #include "folderparser.h"
+#include "homepagetype.h"
+#include "homepagetypeparser.h"
 #include "knowledgebaseentry.h"
 #include "knowledgebaseentryparser.h"
 #include "license.h"
@@ -396,12 +404,31 @@ ListJob< License >* Provider::requestLicenses()
     return job;
 }
 
+ListJob< Distribution >* Provider::requestDistributions()
+{
+    QUrl url = createUrl( "content/distributions" );
+    ListJob<Distribution> *job = new ListJob<Distribution>(d->m_internals, createRequest(url));
+    return job;
+}
+
+ListJob< HomePageType >* Provider::requestHomePageTypes()
+{
+    QUrl url = createUrl( "content/homepages" );
+    ListJob<HomePageType> *job = new ListJob<HomePageType>(d->m_internals, createRequest(url));
+    return job;
+}
+
 ListJob<Content>* Provider::searchContents(const Category::List& categories, const QString& search, SortMode sortMode, uint page, uint pageSize)
 {
-    return searchContentsByPerson(categories, QString(), search, sortMode, page, pageSize);
+    return searchContents(categories, QString(), Distribution::List(), License::List(), search, sortMode, page, pageSize);
 }
 
 ListJob<Content>* Provider::searchContentsByPerson(const Category::List& categories, const QString& person, const QString& search, SortMode sortMode, uint page, uint pageSize)
+{
+    return searchContents(categories, person, Distribution::List(), License::List(), search, sortMode, page, pageSize);
+}
+
+ListJob<Content>* Provider::searchContents(const Category::List& categories, const QString& person, const Distribution::List& distributions, const License::List& licenses, const QString& search, SortMode sortMode, uint page, uint pageSize)
 {
     QUrl url = createUrl( "content/data" );
 
@@ -411,6 +438,18 @@ ListJob<Content>* Provider::searchContentsByPerson(const Category::List& categor
     }
     url.addQueryItem( "categories", categoryIds.join( "x" ) );
 
+    QStringList distributionIds;
+    foreach( const Distribution &distribution, distributions) {
+        distributionIds.append( QString(distribution.id()) );
+    }
+    url.addQueryItem( "distribution", distributionIds.join( "," ) );
+
+    QStringList licenseIds;
+    foreach( const License &license, licenses) {
+        licenseIds.append( QString(license.id()) );
+    }
+    url.addQueryItem( "license", licenseIds.join( "," ) );
+
     if (!person.isEmpty()) {
         url.addQueryItem( "user", person );
     }
@@ -545,6 +584,17 @@ PostJob* Provider::voteForContent(const QString& contentId, bool positiveVote)
 {
     StringMap postParameters;
     postParameters.insert("vote", positiveVote ? "good" : "bad");
+    qDebug() << "vote: " << positiveVote;
+    return new PostJob(d->m_internals, createRequest("content/vote/" + contentId), postParameters);
+}
+
+PostJob* Provider::voteForContent(const QString& contentId, uint rating)
+{
+    // according to OCS API, the rating is 0..100
+    Q_ASSERT(rating <= 100);
+    StringMap postParameters;
+    postParameters.insert("vote", QString::number(rating));
+    qDebug() << "vote: " << QString::number(rating);
     return new PostJob(d->m_internals, createRequest("content/vote/" + contentId), postParameters);
 }
 
@@ -657,6 +707,72 @@ ListJob<Event>* Provider::requestEvent(const QString& country, const QString& se
     return job;
 }
 
+ListJob<Comment>* Provider::requestComments(const Comment::Type commentType, const QString& id, const QString& id2, int page, int pageSize)
+{
+    QString commentTypeString;
+    commentTypeString = Comment::commentTypeToString(commentType);
+    if (commentTypeString.isEmpty()) {
+        return 0;
+    }
+ 
+    QUrl url = createUrl("comments/data/" + commentTypeString + "/" + id + "/" + id2);
+
+    url.addQueryItem("page", QString::number(page));
+    url.addQueryItem("pagesize", QString::number(pageSize));
+
+    ListJob<Comment>* job = new ListJob<Comment>(d->m_internals, createRequest(url));
+    return job;
+}
+
+PostJob* Provider::addNewComment(const Comment::Type commentType, const QString& id, const QString& id2, const QString& parentId, const QString &subject, const QString& message)
+{
+    QString commentTypeString;
+    commentTypeString = Comment::commentTypeToString(commentType);
+    if (commentTypeString.isEmpty()) {
+        return 0;
+    }
+
+    QMap<QString, QString> postParameters;
+
+    postParameters.insert("type", commentTypeString);
+    postParameters.insert("content", id);
+    postParameters.insert("content2", id2);
+    postParameters.insert("parent", parentId);
+    postParameters.insert("subject", subject);
+    postParameters.insert("message", message);
+
+    return new PostJob(d->m_internals, createRequest("comments/add"), postParameters);
+}
+
+PostJob* Provider::voteForComment(const QString & id, uint rating)
+{
+    if (rating > 100) {
+        return 0;
+    }
+
+    QMap<QString, QString> postParameters;
+    postParameters.insert("vote", QString::number(rating));
+
+    QUrl url = createUrl("comments/vote/" + id);
+    return new PostJob(d->m_internals, createRequest(url), postParameters);
+}
+
+PostJob* Provider::setPrivateData(const QString& app, const QString& key, const QString& value)
+{
+    QUrl url = createUrl("privatedata/setattribute/" + app + "/" + key);
+    PostFileData postRequest(url);
+
+    postRequest.addArgument("value", value);
+
+    return new PostJob(d->m_internals, postRequest.request(), postRequest.data());
+}
+
+ItemJob<PrivateData>* Provider::requestPrivateData(const QString& app, const QString& key)
+{
+    ItemJob<PrivateData>* job = new ItemJob<PrivateData>(d->m_internals, createRequest("privatedata/getattribute/" + app + "/" + key));
+    return job;
+}
+
 QUrl Provider::createUrl(const QString& path)
 {
     QUrl url(d->m_baseUrl.toString() + path);
